==> orthanc_0.7.6+dfsg.orig.tar.xz: Orthanc-0.7.6/Core/FileStorage/FileStorageAccessor.cpp <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2014 Medical Physics Department, CHU of Liege,
 * Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#include "../PrecompiledHeaders.h"
#include "FileStorageAccessor.h"

namespace Orthanc
{
  FileInfo FileStorageAccessor::WriteInternal(const void* data,
                                              size_t size,
                                              FileContentType type)
  {
    std::string md5;

    if (storeMD5_)
    {
      Toolbox::ComputeMD5(md5, data, size);
    }

    return FileInfo(storage_.Create(data, size), type, size, md5);
  }
}

==> orthanc_0.8.4+dfsg.orig.tar.xz: Orthanc-0.8.4/Core/FileStorage/FileStorageAccessor.cpp <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2014 Medical Physics Department, CHU of Liege,
 * Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#include "../PrecompiledHeaders.h"
#include "FileStorageAccessor.h"

#include "../HttpServer/BufferHttpSender.h"
#include "../Uuid.h"

#include <memory>
#include <stdio.h>

namespace Orthanc
{
  FileInfo FileStorageAccessor::WriteInternal(const void* data,
                                              size_t size,
                                              FileContentType type)
  {
    std::string md5;

    if (storeMD5_)
    {
      Toolbox::ComputeMD5(md5, data, size);
    }

    std::string uuid = Toolbox::GenerateUuid();
    storage_.Create(uuid.c_str(), data, size, type);

    return FileInfo(uuid, type, size, md5);
  }


  HttpFileSender* FileStorageAccessor::ConstructHttpFileSender(const std::string& uuid,
                                                               FileContentType type)
  {
    std::auto_ptr<BufferHttpSender> sender(new BufferHttpSender);

    storage_.Read(sender->GetBuffer(), uuid, type);
      
    return sender.release();
  }

}
